{ config, pkgs, ... }:

{
  imports = [
    <nixos-hardware/lenovo/thinkpad/t420>
    <nixos-hardware/common/pc/ssd>
    # <musnix>
    ./hardware-configuration.nix
  ];

  nix = rec {
    allowedUsers = [ "root" "lyla" ];
    trustedUsers = allowedUsers;
    gc = {
      automatic = true;
      dates = "weekly";
      options = "--delete-older-than 30d";
    };
  };
  nixpkgs.config = {
    allowUnfree = true;
  };

  boot = {
    loader.grub = {
      enable = true;
      version = 2;
      device = "/dev/sda";
    };
    plymouth.enable = true;
    cleanTmpDir = true;
    kernelPackages = pkgs.linuxPackages_latest;
  };

  security = {
    sudo = {
      enable = true;
      wheelNeedsPassword = false;
    };
  };

  networking = {
    hostName = "crow";
    networkmanager.enable = true;
  };

  i18n.defaultLocale = "en_US.UTF-8";
  console = {
    font = "Lat2-Terminus16";
    keyMap = "la-latin1";
  };

  time.timeZone = "America/Santiago";
  location = {
    latitude = -29.909349;
    longitude = -71.250038;
  };

  environment = {
    homeBinInPath = true;
    systemPackages = with pkgs; [
      # CLI utils
      xclip wget usbutils
      # audio
      # qjackctl
    ];
  };

  fonts = {
    fonts = with pkgs; [
      noto-fonts noto-fonts-cjk noto-fonts-emoji
      inter mononoki tamzen terminus_font
    ];
    fontconfig = {
      enable = true;
      subpixel.rgba = "none";
      defaultFonts = {
        sansSerif = [ "Inter" "Noto Sans" ];
        serif = [ "Noto Serif" ];
        monospace = [ "mononoki" ];
      };
    };
  };

  sound.enable = true;

  # musnix = {
  #   enable = true;
  #   alsaSeq.enable = true;
  #   kernel = {
  #     optimize = true;
  #     realtime = true;
  #     packages = pkgs.linuxPackages_latest_rt;
  #   };
  #   das_watchdog.enable = true;
  # };

  hardware = {
    # enableAllFirmware = true;
    bluetooth.enable = true;
    pulseaudio = {
      enable = true;
      package = pkgs.pulseaudioFull;
    };
    opengl.enable = true;
  };

  programs = {
    adb.enable = true;
    tmux.enable = true;
    slock.enable = true;
    fish.enable = true;
  };

  services = {
    blueman.enable = true;
    # jack = {
    #   jackd.enable = true;
    #   alsa.enable = true;
    # };
    xserver = {
      enable = true;
      layout = "latam";
      libinput.enable = true;
      displayManager = {
        autoLogin = {
          enable = true;
          user = "lyla";
        };
        lightdm = {
          enable = true;
        };
      };      
      desktopManager.xfce = {
        enable = true;
        # thunarPlugins = with pkgs.xfce; [
        #   thunar-volman thunar-archive-plugin
        # ];
      };
    };
    picom = {
      enable = true;
      shadow = false;
      menuOpacity = 0.9;
      inactiveOpacity = 0.95;
      backend = "glx";
      experimentalBackends = true;
    };
    redshift.enable = true;
  };

  users = {
    mutableUsers = false;
    users.lyla = (import ./users/lyla.nix) pkgs;
  };

  system.stateVersion = "21.03";
}

